@@ -17,15 +17,15 @@ from functools import partial
 import jax
 import jax.numpy as jnp
 
-import pgx
-from pgx.flax.struct import dataclass
+import pgx.core as core
+from pgx._flax.struct import dataclass
 
 FALSE = jnp.bool_(False)
 TRUE = jnp.bool_(True)
 
 
 @dataclass
-class State(pgx.State):
+class State(core.State):
     steps: jnp.ndarray = jnp.int32(0)
     size: jnp.ndarray = jnp.int8(11)
     current_player: jnp.ndarray = jnp.int8(0)
@@ -45,33 +45,29 @@ class State(pgx.State):
     #  .
     #  [110, 111, 112, ...,  119, 120]]
     board: jnp.ndarray = -jnp.zeros(
-        11 * 11, jnp.int16
+        11 * 11, jnp.int32
     )  # <0(oppo), 0(empty), 0<(self)
 
 
-class Hex(pgx.Env):
+class Hex(core.Env):
     def __init__(
         self,
         *,
-        auto_reset: bool = False,
-        max_truncation_steps: int = -1,
         size: int = 11,
     ):
-        super().__init__(
-            auto_reset=auto_reset, max_truncation_steps=max_truncation_steps
-        )
+        super().__init__()
         assert isinstance(size, int)
         self.size = size
 
     def _init(self, key: jax.random.KeyArray) -> State:
         return partial(init, size=self.size)(rng=key)
 
-    def _step(self, state: pgx.State, action: jnp.ndarray) -> State:
+    def _step(self, state: core.State, action: jnp.ndarray) -> State:
         assert isinstance(state, State)
         return partial(step, size=self.size)(state, action)
 
     def _observe(
-        self, state: pgx.State, player_id: jnp.ndarray
+        self, state: core.State, player_id: jnp.ndarray
     ) -> jnp.ndarray:
         assert isinstance(state, State)
         return partial(observe, size=self.size)(state, player_id)
