@@ -15,8 +15,8 @@
 import jax
 import jax.numpy as jnp
 
-import pgx
-from pgx.flax.struct import dataclass
+import pgx.core as core
+from pgx._flax.struct import dataclass
 
 FALSE = jnp.bool_(False)
 TRUE = jnp.bool_(True)
@@ -38,7 +38,7 @@ IDX = jnp.int8(
 
 
 @dataclass
-class State(pgx.State):
+class State(core.State):
     steps: jnp.ndarray = jnp.int32(0)
     current_player: jnp.ndarray = jnp.int8(0)
     observation: jnp.ndarray = jnp.zeros(27, dtype=jnp.bool_)
@@ -55,26 +55,21 @@ class State(pgx.State):
     board: jnp.ndarray = -jnp.ones(9, jnp.int8)  # -1 (empty), 0, 1
 
 
-class TicTacToe(pgx.Env):
+class TicTacToe(core.Env):
     def __init__(
         self,
-        *,
-        auto_reset: bool = False,
-        max_truncation_steps: int = -1,
     ):
-        super().__init__(
-            auto_reset=auto_reset, max_truncation_steps=max_truncation_steps
-        )
+        super().__init__()
 
     def _init(self, key: jax.random.KeyArray) -> State:
         return init(key)
 
-    def _step(self, state: pgx.State, action: jnp.ndarray) -> State:
+    def _step(self, state: core.State, action: jnp.ndarray) -> State:
         assert isinstance(state, State)
         return step(state, action)
 
     def _observe(
-        self, state: pgx.State, player_id: jnp.ndarray
+        self, state: core.State, player_id: jnp.ndarray
     ) -> jnp.ndarray:
         assert isinstance(state, State)
         return observe(state, player_id)
