@@ -16,7 +16,9 @@ from pgx.animal_shogi import (
     _action_to_dlaction,
     _dlaction_to_action,
     _update_legal_move_actions,
-    _update_legal_drop_actions
+    _update_legal_drop_actions,
+    _filter_suicide_actions,
+    _filter_leave_check_actions
 )
 import jax.numpy as np
 import jax
@@ -38,6 +40,8 @@ _action_to_dlaction = jax.jit(_action_to_dlaction)
 _dlaction_to_action = jax.jit(_dlaction_to_action)
 _update_legal_move_actions = jax.jit(_update_legal_move_actions)
 _update_legal_drop_actions = jax.jit(_update_legal_drop_actions)
+_filter_suicide_actions = jax.jit(_filter_suicide_actions)
+_filter_leave_check_actions = jax.jit(_filter_leave_check_actions)
 
 
 TEST_BOARD = AnimalShogiState(
@@ -425,3 +429,81 @@ def test_step():
             assert t
         else:
             assert not t
+
+
+def test_filter_suicide_action():
+    bs = np.array([6, 0, 0, 7, 0, 0, 4, 0, 8, 0, 0, 0], dtype=np.int32)
+    board = np.zeros((11, 12), dtype=np.int32)
+    for i in range(12):
+        board = board.at[0, i].set(0)
+        board = board.at[bs[i], i].set(1)
+    state = AnimalShogiState(board=board)
+    state = _init_legal_actions(state)
+    origin_actions = state.legal_actions_black
+    filtered_actions = _filter_suicide_actions(0, 6, _effected_positions(state, 1), origin_actions)
+    b_actions = np.zeros(180, dtype=np.int32)
+    b_actions = b_actions.at[87].set(True)
+    b_actions = b_actions.at[21].set(True)
+    b_actions = b_actions.at[46].set(True)
+    b_actions = b_actions.at[83].set(True)
+    assert np.allclose(filtered_actions, b_actions)
+    bs2 = np.array([9, 0, 1, 0, 0, 0, 0, 0, 4, 0, 0, 0], dtype=np.int32)
+    board2 = np.zeros((11, 12), dtype=np.int32)
+    for i in range(12):
+        board2 = board2.at[0, i].set(0)
+        board2 = board2.at[bs2[i], i].set(1)
+    state2 = AnimalShogiState(turn=1, board=board2)
+    state2 = _init_legal_actions(state2)
+    origin_actions2 = state2.legal_actions_white
+    filtered_actions2 = _filter_suicide_actions(1, 0, _effected_positions(state2, 0), origin_actions2)
+    assert np.allclose(filtered_actions2, np.zeros(180, dtype=np.int32))
+    state2 = AnimalShogiState(board=board2)
+    state2 = _init_legal_actions(state2)
+    origin_actions3 = state2.legal_actions_black
+    filtered_actions3 = _filter_suicide_actions(0, 8, _effected_positions(state2, 1), origin_actions3)
+    b_actions2 = np.zeros(180, dtype=np.int32)
+    b_actions2 = b_actions2.at[1].set(1)
+    b_actions2 = b_actions2.at[69].set(1)
+    assert np.allclose(filtered_actions3, b_actions2)
+
+
+def test_filter_leave_check():
+    bs = np.array([3, 0, 0, 0, 2, 6, 4, 0, 8, 0, 0, 0], dtype=np.int32)
+    board = np.zeros((11, 12), dtype=np.int32)
+    for i in range(12):
+        board = board.at[0, i].set(0)
+        board = board.at[bs[i], i].set(1)
+    state = AnimalShogiState(board=board)
+    state = _init_legal_actions(state)
+    origin_actions = state.legal_actions_black
+    cp = np.array([0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0], dtype=np.int32)
+    filtered_actions = _filter_leave_check_actions(0, 6, cp, origin_actions)
+    b_actions = np.zeros(180, dtype=np.int32)
+    b_actions = b_actions.at[65].set(True)
+    b_actions = b_actions.at[77].set(True)
+    b_actions = b_actions.at[5].set(True)
+    b_actions = b_actions.at[21].set(True)
+    b_actions = b_actions.at[25].set(True)
+    b_actions = b_actions.at[46].set(True)
+    b_actions = b_actions.at[50].set(True)
+    b_actions = b_actions.at[67].set(True)
+    b_actions = b_actions.at[83].set(True)
+    b_actions = b_actions.at[87].set(True)
+    assert np.allclose(filtered_actions, b_actions)
+    bs2 = np.array([9, 7, 0, 0, 6, 3, 0, 0, 0, 0, 0, 0], dtype=np.int32)
+    board2 = np.zeros((11, 12), dtype=np.int32)
+    for i in range(12):
+        board2 = board2.at[0, i].set(0)
+        board2 = board2.at[bs2[i], i].set(1)
+    state2 = AnimalShogiState(board=board2)
+    state2 = _init_legal_actions(state2)
+    origin_actions2 = state2.legal_actions_white
+    cp2 = np.array([0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0], dtype=np.int32)
+    filtered_actions2 = _filter_leave_check_actions(1, 0, cp2, origin_actions2)
+    b_actions2 = np.zeros(180, dtype=np.int32)
+    b_actions2 = b_actions2.at[1].set(True)
+    b_actions2 = b_actions2.at[52].set(True)
+    b_actions2 = b_actions2.at[5].set(True)
+    b_actions2 = b_actions2.at[29].set(True)
+    b_actions2 = b_actions2.at[53].set(True)
+    assert np.allclose(filtered_actions2, b_actions2)
\ No newline at end of file
